@@ -2,7 +2,7 @@ package ModPerl::RegistryCookerSealed;
 use strict;
 use warnings;
 use version;
-our $VERSION = qv(1.2.0);
+our $VERSION = qv(1.3.0);
 
 use Apache2::Const -compile => qw(:common &OPT_EXECCGI);
 use ModPerl::RegistryCooker;
@@ -43,12 +43,14 @@ sub convert_script_to_compiled_handler {
   my $script_name = $self->get_script_name || $0;
 
   # handle sealed.pm's source filter ourselves, since the string eval won't.
-  sealed::source_munger($self->{PACKAGE}, 1) for ${$self->{CODE}};
+  sealed::source_munger($self->{PACKAGE}) for ${$self->{CODE}};
 
   my $eval = join '',
     'package ',
     $self->{PACKAGE}, ";",
     "use base 'sealed';",
+    "use types;",
+    "use class;",
     "sub handler :Sealed {",
     "local \$0 = '$script_name';",
     $nph,
